@@ -10,8 +10,8 @@ def configure_logger() -> logging.Logger:
     logger = logging.getLogger("dbrocket")
     logger.addHandler(logging.StreamHandler(sys.stdout))
     # use this for debug purposes
-    logger.setLevel(logging.DEBUG)
-    # logger.setLevel(logging.INFO)
+    # logger.setLevel(logging.DEBUG)
+    logger.setLevel(logging.INFO)
     return logger
 
 
@@ -26,7 +26,9 @@ class Rocket:
     _python_executable: str = "python3"
     _rocket_executable: str = "rocket"
 
-    def trigger(self, project_location: str, dbfs_path: str, watch=True, disable_watch=False):
+    def trigger(
+        self, project_location: str, dbfs_path: str, watch=True, disable_watch=False
+    ):
         """
         Entrypoint of the application, triggers a build and deploy
         :param project_location:
@@ -59,10 +61,10 @@ class Rocket:
         Listen to filesystem changes to trigger again
         """
 
-        command = sys.argv
+        command_list = sys.argv
         # disable watch takes precedence over --enable
-        command.append('--disable_watch=True')
-        command = " ".join(command)
+        command_list.append("--disable_watch=True")
+        command = " ".join(command_list)
 
         cmd = f"""watchmedo \
                 shell-command \
@@ -134,7 +136,7 @@ Or if you are running spark 6 use this command instead (and clean the state befo
     def _hello(self):
         print(
             """
-        Greetings from db-rocket :) 
+        Greetings from db-rocket :)
         Version 2n
         """
         )
